@@ -17,31 +17,21 @@ package external
 
 import (
 	"context"
-	"crypto/sha256"
-	"encoding/hex"
 	"fmt"
 	"io"
 	"net/http"
-	"os"
-	"strings"
 
 	"cloud.google.com/go/storage"
-	"github.com/GoogleCloudPlatform/osconfig/util"
 )
 
 // FetchGCSObject fetches data from GCS bucket
-func FetchGCSObject(ctx context.Context, client *storage.Client, object, bucket string, generation int64) (io.ReadCloser, error) {
+func FetchGCSObject(ctx context.Context, client *storage.Client, bucket, object string, generation int64) (io.ReadCloser, error) {
 	oh := client.Bucket(bucket).Object(object)
 	if generation != 0 {
 		oh = oh.Generation(generation)
 	}
 
-	r, err := oh.NewReader(ctx)
-	if err != nil {
-		return nil, err
-	}
-
-	return r, nil
+	return oh.NewReader(ctx)
 }
 
 // FetchRemoteObjectHTTP fetches data from remote location
@@ -57,26 +47,3 @@ func FetchRemoteObjectHTTP(client *http.Client, url string) (io.ReadCloser, erro
 
 	return resp.Body, nil
 }
-
-// DownloadStream fetches data from an input stream
-func DownloadStream(r io.ReadCloser, checksum, localPath string, mode os.FileMode) error {
-	localPath, err := util.NormPath(localPath)
-	if err != nil {
-		return err
-	}
-	file, err := os.OpenFile(localPath, os.O_RDWR|os.O_CREATE|os.O_TRUNC, mode)
-	if err != nil {
-		return err
-	}
-	defer file.Close()
-
-	hasher := sha256.New()
-	if _, err = io.Copy(io.MultiWriter(file, hasher), r); err != nil {
-		return err
-	}
-	computed := hex.EncodeToString(hasher.Sum(nil))
-	if checksum != "" && !strings.EqualFold(checksum, computed) {
-		return fmt.Errorf("got %q for checksum, expected %q", computed, checksum)
-	}
-	return nil
-}
