@@ -18,13 +18,18 @@ package util
 import (
 	"bytes"
 	"context"
+	"crypto/sha256"
+	"encoding/hex"
 	"fmt"
-	"io/ioutil"
+	"io"
+	"math/rand"
 	"os"
 	"os/exec"
 	"path/filepath"
 	"runtime"
+	"strconv"
 	"strings"
+	"time"
 
 	"github.com/GoogleCloudPlatform/osconfig/clog"
 	"google.golang.org/protobuf/encoding/protojson"
@@ -77,6 +82,45 @@ func Exists(name string) bool {
 	return true
 }
 
+// AtomicWriteFileStream attempts to atomically write data from the provided reader to the path
+// checking the checksum if provided.
+func AtomicWriteFileStream(r io.Reader, checksum, path string, mode os.FileMode) (string, error) {
+	path, err := NormPath(path)
+	if err != nil {
+		return "", err
+	}
+
+	tmp, err := TempFile(filepath.Dir(path), filepath.Base(path), mode)
+	if err != nil {
+		return "", fmt.Errorf("unable to create temp file: %v", err)
+	}
+
+	tmpName := tmp.Name()
+	// Make sure we cleanup on any errors.
+	defer func() {
+		if err != nil {
+			tmp.Close()
+			os.Remove(tmpName)
+		}
+	}()
+
+	hasher := sha256.New()
+	if _, err = io.Copy(io.MultiWriter(tmp, hasher), r); err != nil {
+		return "", err
+	}
+
+	computed := hex.EncodeToString(hasher.Sum(nil))
+	if checksum != "" && !strings.EqualFold(checksum, computed) {
+		return "", fmt.Errorf("got %q for checksum, expected %q", computed, checksum)
+	}
+
+	if err := tmp.Close(); err != nil {
+		return "", err
+	}
+
+	return computed, os.Rename(tmpName, path)
+}
+
 // CommandRunner will execute the commands and return the results of that
 // execution.
 type CommandRunner interface {
@@ -97,9 +141,22 @@ func (r *DefaultRunner) Run(ctx context.Context, cmd *exec.Cmd) ([]byte, []byte,
 	return stdout.Bytes(), stderr.Bytes(), err
 }
 
+// TempFile is a little bit like ioutil.TempFile but takes FileMode in
+// order to work nicely on Windows where File.Chmod is not supported.
+func TempFile(dir string, pattern string, mode os.FileMode) (f *os.File, err error) {
+	r := strconv.Itoa(rand.New(rand.NewSource(time.Now().UnixNano())).Intn(99999))
+	name := filepath.Join(dir, pattern+r+".tmp")
+	return os.OpenFile(name, os.O_RDWR|os.O_CREATE|os.O_EXCL, mode)
+}
+
 // AtomicWrite attempts to atomically write a file.
 func AtomicWrite(path string, content []byte, mode os.FileMode) (err error) {
-	tmp, err := ioutil.TempFile(filepath.Dir(path), filepath.Base(path)+".tmp*")
+	path, err = NormPath(path)
+	if err != nil {
+		return err
+	}
+
+	tmp, err := TempFile(filepath.Dir(path), filepath.Base(path), mode)
 	if err != nil {
 		return fmt.Errorf("unable to create temp file: %v", err)
 	}
@@ -116,9 +173,6 @@ func AtomicWrite(path string, content []byte, mode os.FileMode) (err error) {
 	if _, err := tmp.Write(content); err != nil {
 		return err
 	}
-	if err := tmp.Chmod(mode); err != nil {
-		return err
-	}
 	if err := tmp.Close(); err != nil {
 		return err
 	}
